changeset 26883:a365271c97a5

Revert commit r26897. XviD is the correct spelling of the codec. You can see it written in the codec own documentation and header files. Prefered name capitalization confirmed in conversation with XviD developer (prunedtree).
author iive
date Wed, 28 May 2008 23:04:41 +0000
parents 8eacd1538e64
children cb9430d7bf56
files AUTHORS DOCS/tech/MAINTAINERS DOCS/tech/encoding-guide.txt DOCS/tech/encoding-tips.txt configure etc/codecs.conf libmpcodecs/vd_xvid4.c libmpcodecs/ve_xvid4.c
diffstat 8 files changed, 21 insertions(+), 21 deletions(-) [+]
line wrap: on
line diff
--- a/AUTHORS	Wed May 28 12:40:15 2008 +0000
+++ b/AUTHORS	Wed May 28 23:04:41 2008 +0000
@@ -335,7 +335,7 @@
 Guyomarch, Rémi (rguyom) <rguyom@pobox.com>
     * various fixes
     * unsharp video filter
-    * Xvid encoding support
+    * XviD encoding support
 
 Hall, Julian <jules@meridiandigital.co.uk>
     * black frame detection filter (vf_blackframe)
@@ -642,7 +642,7 @@
 
 Poirier, Guillaume (poirierg) <poirierg@gmail.com>
     * French documentation translation and synchronization
-    * Xvid documentation
+    * XviD documentation
     * libavcodec turbo mode
     * lots of updates of MEncoder's documentation
     * code fixes to support GCC-4.0
@@ -751,7 +751,7 @@
 
 Swain, Robert <robert.swain@gmail.com>
     * CQM support and turbo multipass mode in x264 interface
-    * Profile support in Xvid interface
+    * Profile support in XviD interface
 
 Syrjälä, Ville <syrjala@sci.fi>
     * -vo dfbmga driver (G400 DVDMax-like feature using dfb 0.9.14)
--- a/DOCS/tech/MAINTAINERS	Wed May 28 12:40:15 2008 +0000
+++ b/DOCS/tech/MAINTAINERS	Wed May 28 23:04:41 2008 +0000
@@ -134,7 +134,7 @@
 
 codec support:
     * FFmpeg: Michael Niedermayer
-    * Xvid: Ivan Kalvachev
+    * XviD: Ivan Kalvachev
     * x264: Loren Merritt
     * musepack, speex: Reimar Döffinger
 
--- a/DOCS/tech/encoding-guide.txt	Wed May 28 12:40:15 2008 +0000
+++ b/DOCS/tech/encoding-guide.txt	Wed May 28 23:04:41 2008 +0000
@@ -122,7 +122,7 @@
 the first-pass file before beginning the second pass to make sure
 nothing went wrong in the encoding.
 
-Next, an example using Xvid instead of libavcodec:
+Next, an example using XviD instead of libavcodec:
 
   Encoding from an existing AVI file
   500 kbit/sec MPEG-4 video
--- a/DOCS/tech/encoding-tips.txt	Wed May 28 12:40:15 2008 +0000
+++ b/DOCS/tech/encoding-tips.txt	Wed May 28 23:04:41 2008 +0000
@@ -304,7 +304,7 @@
 good results are with ~50, and everything above 60 is a waste of bandwidth.
 And what's actually funny is that it was independent of codec used. The
 results were exactly the same, whether I used DIV3 (with tricky nandub's
-magick), ffmpeg odivx, DivX5 on Windows or Xvid.
+magick), ffmpeg odivx, DivX5 on Windows or XviD.
 
 Surprisingly there is one advantage of using nandub-DIV3 for bitrate
 starved encoding: ringing almost never apears this way.
--- a/configure	Wed May 28 12:40:15 2008 +0000
+++ b/configure	Wed May 28 23:04:41 2008 +0000
@@ -286,8 +286,8 @@
   --disable-qtx             disable QuickTime codecs support [enabled]
   --disable-xanim           disable XAnim codecs support [enabled]
   --disable-real            disable RealPlayer codecs support [enabled]
-  --disable-xvid            disable Xvid [autodetect]
-  --disable-xvid-lavc       disable Xvid in libavcodec [autodetect]
+  --disable-xvid            disable XviD [autodetect]
+  --disable-xvid-lavc       disable XviD in libavcodec [autodetect]
   --disable-x264            disable x264 [autodetect]
   --disable-x264-lavc       disable x264 in libavcodec [autodetect]
   --disable-libnut          disable libnut [autodetect]
@@ -6533,7 +6533,7 @@
 echores "$_libdv"
 
 
-echocheck "Xvid"
+echocheck "XviD"
 if test "$_xvid" = auto ; then
   _xvid=no
   cat > $TMPC << EOF
@@ -6554,7 +6554,7 @@
 fi
 echores "$_xvid"
 
-echocheck "Xvid two pass plugin"
+echocheck "XviD two pass plugin"
 if test "$_xvid" = yes && test "$_xvid_lavc" = auto ; then
   cat > $TMPC << EOF
 #include <xvid.h>
@@ -7936,7 +7936,7 @@
    -cache <kilobytes> */
 $_def_stream_cache
 
-/* Define if you are using Xvid library */
+/* Define if you are using XviD library */
 $_def_xvid
 
 /* Define if you are using the X.264 library */
--- a/etc/codecs.conf	Wed May 28 12:40:15 2008 +0000
+++ b/etc/codecs.conf	Wed May 28 23:04:41 2008 +0000
@@ -700,7 +700,7 @@
   out YV12,I420,IYUV flip
 
 videocodec xvid
-  info "Xvid (MPEG-4)"
+  info "XviD (MPEG-4)"
   status working
   fourcc FMP4,fmp4
   fourcc DIVX,divx
--- a/libmpcodecs/vd_xvid4.c	Wed May 28 12:40:15 2008 +0000
+++ b/libmpcodecs/vd_xvid4.c	Wed May 28 23:04:41 2008 +0000
@@ -1,5 +1,5 @@
 /*
  * - Xvid 1.x decoder module for mplayer/mencoder -
  *
  * Copyright(C) 2003      Marco Belli <elcabesa@inwind.it>
  *              2003-2004 Edouard Gomez <ed.gomez@free.fr>
@@ -170,7 +170,7 @@
 
 	/* Get a decoder instance */
 	if(xvid_decore(0, XVID_DEC_CREATE, &dec_p, NULL)<0) {
-		mp_msg(MSGT_DECVIDEO, MSGL_ERR, "Xvid init failed\n");
+		mp_msg(MSGT_DECVIDEO, MSGL_ERR, "XviD init failed\n");
 		return 0;
 	}
 
@@ -380,7 +380,7 @@
 
 static vd_info_t info = 
 {
-	"Xvid 1.0 decoder",
+	"XviD 1.0 decoder",
 	"xvid",
 	"Marco Belli <elcabesa@inwind.it>, Edouard Gomez <ed.gomez@free.fr>",
 	"Marco Belli <elcabesa@inwind.it>, Edouard Gomez <ed.gomez@free.fr>",
@@ -1,5 +1,5 @@
 /*
- * - Xvid 1.x decoder module for mplayer/mencoder -
+ * - XviD 1.x decoder module for mplayer/mencoder -
  *
  * Copyright(C) 2003      Marco Belli <elcabesa@inwind.it>
--- a/libmpcodecs/ve_xvid4.c	Wed May 28 12:40:15 2008 +0000
+++ b/libmpcodecs/ve_xvid4.c	Wed May 28 23:04:41 2008 +0000
@@ -1,5 +1,5 @@
 /*
  * - Xvid 1.x decoder module for mplayer/mencoder -
  *
  * Copyright(C) 2003      Marco Belli <elcabesa@inwind.it>
  *              2003-2004 Edouard Gomez <ed.gomez@free.fr>
@@ -96,7 +96,7 @@
 	unsigned int flags;          ///< flags for allowed options/dxn note the definitions for PROFILE_S and PROFILE_AS
 } profile_t;
 
 // Code taken from Xvid VfW source for profile support
 
 /* default vbv_occupancy is (64/170)*vbv_buffer_size */
 
@@ -390,7 +390,7 @@
 
 	/* Message the FourCC type */
 	mp_msg(MSGT_MENCODER, MSGL_INFO,
-	       "videocodec: Xvid (%dx%d fourcc=%x [%.4s])\n",
+	       "videocodec: XviD (%dx%d fourcc=%x [%.4s])\n",
 	       width, height, mod->mux->bih->biCompression,
 	       (char *)&mod->mux->bih->biCompression);
 
@@ -398,7 +398,7 @@
 	mod->pixels = mod->mux->bih->biWidth*mod->mux->bih->biHeight;
 
 	/*--------------------------------------------------------------------
 	 * Dispatch all module settings to Xvid structures
 	 *------------------------------------------------------------------*/
 
 	mod->d_width = d_width;
@@ -617,7 +617,7 @@
 	mod->mux->bih->biBitCount = 12;
 	mod->mux->bih->biCompression = mmioFOURCC('X','V','I','D');
 
 	/* Retrieve information about the host Xvid library */
 	memset(&xvid_gbl_info, 0, sizeof(xvid_gbl_info_t));
 	xvid_gbl_info.version = XVID_VERSION;
 
@@ -1515,7 +1515,7 @@
  ****************************************************************************/
 
 vf_info_t ve_info_xvid = {
-	"Xvid 1.0 encoder",
+	"XviD 1.0 encoder",
 	"xvid",
 	"Marco Belli <elcabesa@inwind.it>, Edouard Gomez <ed.gomez@free.fr>",
 	"No comment",
@@ -1,5 +1,5 @@
 /*
- * - Xvid 1.x decoder module for mplayer/mencoder -
+ * - XviD 1.x decoder module for mplayer/mencoder -
  *
  * Copyright(C) 2003      Marco Belli <elcabesa@inwind.it>
@@ -96,7 +96,7 @@
 } profile_t;
 
-// Code taken from Xvid VfW source for profile support
+// Code taken from XviD VfW source for profile support
 
 /* default vbv_occupancy is (64/170)*vbv_buffer_size */
@@ -398,7 +398,7 @@
 
 	/*--------------------------------------------------------------------
-	 * Dispatch all module settings to Xvid structures
+	 * Dispatch all module settings to XviD structures
 	 *------------------------------------------------------------------*/
 
@@ -617,7 +617,7 @@
 	mod->mux->bih->biCompression = mmioFOURCC('X','V','I','D');
 
-	/* Retrieve information about the host Xvid library */
+	/* Retrieve information about the host XviD library */
 	memset(&xvid_gbl_info, 0, sizeof(xvid_gbl_info_t));
 	xvid_gbl_info.version = XVID_VERSION;